﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Tsi1.BusinessLayer.DataLoad;

namespace Tsi1.Api.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class DataLoadController : ControllerBase
    {
        private readonly IDataLoad _dataLoad;

        public DataLoadController(IDataLoad dataLoad)
        {
            _dataLoad = dataLoad;
        }

        [AllowAnonymous]
        [HttpGet("LoadData")]
        public async Task<IActionResult> LoadData()
        {
            await _dataLoad.LoadDataAsync();

            return Ok();
        }

        [AllowAnonymous]
        [HttpPost("LoadStudentsInBedelia")]
        public async Task<IActionResult> LoadStudentsInBedelia()
        {
            try
            {
                var result = await _dataLoad.LoadStudentsInBedelia();
                if (result.HasError)
                {
                    return BadRequest(result.Message);
                }

            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }

            return Ok();
        }

        [AllowAnonymous]
        [HttpPost("LoadCoursesInBedelia")]
        public async Task<IActionResult> LoadCoursesInBedelia()
        {
            try
            {
                var result = await _dataLoad.LoadCoursesInBedelia();
                if (result.HasError)
                {
                    return BadRequest(result.Message);
                }
            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }

            return Ok();
        }
    }
}
